import { defineConfig } from 'astro/config'
import vue from "@astrojs/vue"

// Settings
import { SiteSettings } from './config.json'

// Integrations
import mdx from '@astrojs/mdx'
import pagefind from "astro-pagefind"
import compressor from 'astro-compressor';
import pageInsight from 'astro-page-insight';

// Astro Configuration
export default defineConfig({
    // Top Level
    compressHTML: true,
    // Information
    site: SiteSettings.SiteProtocol + '://' + SiteSettings.SiteDomain,
    base: SiteSettings.SiteBase,
    // Integrations
    integrations: [mdx(), pagefind(), vue(), compressor(), pageInsight()],
    markdown: {
        syntaxHighlight: 'prism'
    },
    // Build
    build: {
      concurrency: 2  
    },
    cacheDir: './dist-cache/',
    // Server Output
    output: "static",
    prefetch: true,
    server: {
        port: 2014,
        host: true
    },
    // Others
    devToolbar: {
        enabled: false
    }
})